@@ -21,6 +21,7 @@
 #include "dialog_relationships.h"
 #include "../box_db_table.h"
 //#include <libgnome/gnome-i18n.h>
+#include <libintl.h>
 
 
 Dialog_Relationships::Dialog_Relationships(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
@@ -42,15 +43,15 @@ Dialog_Relationships::~Dialog_Relationships()
 {
 }
 
-void Dialog_Relationships::init_db_details(const Glib::ustring& strDatabaseName, const Glib::ustring& strTableName)
+void Dialog_Relationships::init_db_details(const Glib::ustring& strTableName)
 {
   if(m_box)
   {
     m_box->load_from_document();
 
-    Dialog_Design::init_db_details(strDatabaseName, strTableName);
+    Dialog_Design::init_db_details(strTableName);
     
-    m_box->init_db_details(strDatabaseName, strTableName);
+    m_box->init_db_details(strTableName);
   }
 }
 
