@@ -24,18 +24,26 @@
 #include "flowtable.h"
 #include "../data_structure/layout/layoutgroup.h"
 #include "../data_structure/layout/layoutitem_field.h"
+#include "../data_structure/layout/layoutitem_portal.h"
 #include "../data_structure/field.h"
+#include "../document/document_glom.h"
+#include "../mode_data/box_data_list_related.h"
 #include <map>
 #include <list>
 
 class DataWidget;
 
-class FlowTableWithFields : public FlowTable
+class FlowTableWithFields
+  : public FlowTable,
+    public View_Composite_Glom
 {
 public: 
-  FlowTableWithFields();
+  FlowTableWithFields(const Glib::ustring& table_name = Glib::ustring());
   virtual ~FlowTableWithFields();
 
+  ///The table name is needed to discover details of relationships.
+  virtual void set_table(const Glib::ustring& table_name);
+
   /** Add a field.
    * @param title The title to show to the left of the entry.
    * @param id The unique identifier for this field, to use with get_field().
@@ -83,6 +91,9 @@ protected:
   virtual type_list_widgets get_field(const Field& field);
   virtual type_list_const_widgets get_field(const Field& field) const;
 
+  ///Get portals whose relationships have @a from_key as the from_key.
+  virtual type_list_widgets get_portals(const Glib::ustring& from_key);
+
   int get_suitable_width(Field::glom_field_type field_type);
   void on_entry_edited(const Gnome::Gda::Value& value, Glib::ustring id);
   void on_flowtable_entry_edited(const Glib::ustring& id, const Gnome::Gda::Value& value);
@@ -107,6 +118,11 @@ protected:
   typedef std::list< FlowTableWithFields* > type_sub_flow_tables;
   type_sub_flow_tables m_sub_flow_tables;
 
+  typedef std::list< Box_Data_List_Related* > type_portals;
+  type_portals m_portals;
+
+  Glib::ustring m_table_name;
+
   type_signal_field_edited m_signal_field_edited;
 };
 
